// java wrapper for vtkExtractCells object
//

package vtk;
import vtk.*;

public class vtkExtractCells extends vtkUnstructuredGridAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCellList_2(vtkIdList id0);
  public void SetCellList(vtkIdList id0)
    { SetCellList_2(id0); }

  private native void AddCellList_3(vtkIdList id0);
  public void AddCellList(vtkIdList id0)
    { AddCellList_3(id0); }

  private native void AddCellRange_4(int id0,int id1);
  public void AddCellRange(int id0,int id1)
    { AddCellRange_4(id0,id1); }

  private native int GetMTime_5();
  public int GetMTime()
    { return GetMTime_5(); }

  public vtkExtractCells() { super(); }

  public vtkExtractCells(long id) { super(id); }
  public native long   VTKInit();

}
